# this specfile is inspired from fedoras'one.
# but I choose not to use git sources, I prefer using tarball
%define tarname pep8
%define fname %{tarname}

Name:           python-%{tarname}
Version:        1.7.1
Release:        %mkrel 9
Summary:        Python style guide checker

Group:          Development/Python
# License is held in the comments of pep8.py
# setup.py claims license is Expat license, which is the same as MIT
License:        MIT
URL:            https://github.com/jcrocholl/pep8
Source0:        https://files.pythonhosted.org/packages/source/p/%{fname}/%{fname}-%{version}.tar.gz
# Patch from Debian to pass tests
Patch0:         python3.7.patch
BuildArch:      noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinx_rtd_theme

%description
pep8 is a tool to check your Python code against some of the style conventions
in PEP 8. It has a plugin architecture, making new checks easy, and its output
is parseable, making it easy to jump to an error location in your editor.

# Python 3 package
%package -n python3-pep8
Summary:    Python style guide checker
%{?python_provide:%python_provide python3-pep8}

%description -n python3-pep8
pep8 is a tool to check your Python code against some of the style
conventions in PEP 8. It has a plugin architecture, making new checks
easy, and its output is parseable, making it easy to jump to an error
location in your editor.

%prep
%setup -qn %{tarname}-%{version}
%autopatch -p1

# Remove #! from pep8.py
sed --in-place "s:#!\s*/usr.*::" pep8.py

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

# generate html docs
PYTHONPATH=${PWD} sphinx-build-3 docs html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}

%install
%pyproject_install
%pyproject_save_files %{tarname}

%if 0
%check
export PYTHONPATH=%{buildroot}%{python3_sitelib}
%{__python3} pep8.py --testsuite testsuite
%{__python3} pep8.py --doctest
%endif

%files -n python3-%{tarname} -f %{pyproject_files}
%doc CHANGES.txt README.rst html
%{_bindir}/pep8


%changelog
* Wed Dec 13 2023 papoteur <papoteur> 1.7.1-9.mga10
+ Revision: 2017788
- rebuild for python 3.12

* Sat Dec 09 2023 wally <wally> 1.7.1-8.mga10
+ Revision: 2015990
- use pyproject rpm macros
- skip tests for now
- rebuild for py3.12

* Tue Mar 29 2022 umeabot <umeabot> 1.7.1-7.mga9
+ Revision: 1832607
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 joequant <joequant> 1.7.1-6.mga9
+ Revision: 1774655
- rebuild to python 3.10

* Mon Mar 15 2021 wally <wally> 1.7.1-5.mga9
+ Revision: 1703656
- rebuild for python 3.9

* Sun Feb 16 2020 umeabot <umeabot> 1.7.1-4.mga8
+ Revision: 1531000
- Mageia 8 Mass Rebuild

* Sun Sep 08 2019 wally <wally> 1.7.1-3.mga8
+ Revision: 1438392
- rebuild for python3.8
- drop python2 support

* Tue Aug 20 2019 wally <wally> 1.7.1-2.mga8
+ Revision: 1430575
- update sphinx BRs

* Mon Jan 07 2019 kekepower <kekepower> 1.7.1-1.mga7
+ Revision: 1350709
- add patch originally from Debian to fix tests with python3.7
- Update to version 1.7.1
- Rebuild for Python 3.7

* Thu Sep 20 2018 umeabot <umeabot> 1.7.0-3.mga7
+ Revision: 1289665
- Mageia 7 Mass Rebuild

* Fri Aug 04 2017 shlomif <shlomif> 1.7.0-2.mga7
+ Revision: 1135033
- rebuild for python3

* Fri May 13 2016 philippem <philippem> 1.7.0-1.mga6
+ Revision: 1014423
- update to 1.7.0

* Fri Feb 19 2016 umeabot <umeabot> 1.6.2-2.mga6
+ Revision: 970728
- Mageia 6 Mass Rebuild

* Fri Oct 09 2015 shlomif <shlomif> 1.6.2-1.mga6
+ Revision: 888099
- Add missing BR on sphinx_rtd_theme
- New version + Rebuild for new Python3 3.5.x

* Wed Oct 15 2014 umeabot <umeabot> 1.5.7-4.mga5
+ Revision: 742761
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.5.7-3.mga5
+ Revision: 729316
- rebuild for missing pythoneggs deps
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Wed Sep 03 2014 grenoya <grenoya> 1.5.7-1.mga5
+ Revision: 671527
- new version 1.5.7

* Sat May 31 2014 pterjan <pterjan> 1.5.6-4.mga5
+ Revision: 628878
- Rebuild for new Python

* Fri May 02 2014 grenoya <grenoya> 1.5.6-3.mga5
+ Revision: 619613
- new version 1.5.6

* Tue Oct 22 2013 umeabot <umeabot> 1.4.6-3.mga4
+ Revision: 544024
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.4.6-2.mga4
+ Revision: 499114
- Rebuild to add different pythonegg provides for python 2 and 3

* Tue Oct 01 2013 grenoya <grenoya> 1.4.6-1.mga4
+ Revision: 490010
- new version 1.4.6
- add python3 module
- add check section
- add documentation build

* Fri Jun 07 2013 grenoya <grenoya> 1.4.5-1.mga4
+ Revision: 440277
- new version 1.4.5

* Sun Jan 13 2013 umeabot <umeabot> 1.3.3-2.mga3
+ Revision: 379266
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jul 18 2012 grenoya <grenoya> 1.3.3-1.mga3
+ Revision: 272324
- new version (1.3.3)

* Sun Sep 11 2011 grenoya <grenoya> 0.6.1-1.mga2
+ Revision: 142475
- import package from Fedora
- switch from git version to last tarball version
- clean spec
- imported package python-pep8


* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Jan 21 2011 Ian Weller <iweller@redhat.com> - 0.6.0-2
- RHBZ 633102: Requires: python-setuptools

* Tue Nov 16 2010 Ian Weller <iweller@redhat.com> - 0.6.0-1
- Changed upstream (same code, new maintainer, new URL)
- New release

* Thu Jul 22 2010 David Malcolm <dmalcolm@redhat.com> - 0.4.2-3
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Mon Nov  9 2009 Ian Weller <ian@ianweller.org> - 0.4.2-2
- Add BR: python-setuptools
- Change URL to the correct upstream

* Sun Nov  8 2009 Ian Weller <ian@ianweller.org> - 0.4.2-1
- Initial package build
